﻿using System.Windows;
using System.Windows.Controls;

using System.Windows.Media;


namespace XMachineControl
{

	public enum OnOffDisplayMode
	{
		leftRect,
		rightRect,
		fullRect,
	}
	/// <summary>
	/// XOnOffDisplay.xaml에 대한 상호 작용 논리
	/// </summary>
	public partial class XOnOffDisplay : UserControl
	{
		string desc;

		private System.Windows.Media.Brush onColor = System.Windows.Media.Brushes.Lime;
		private System.Windows.Media.Brush offColor = System.Windows.Media.Brushes.Gray;

		OnOffDisplayMode dispMode = OnOffDisplayMode.leftRect;

		public XOnOffDisplay()
		{
			InitializeComponent();
			desc = lblDesc.Content.ToString();
		}


		public static readonly DependencyProperty PropertyChecked = DependencyProperty.Register("Checked", typeof(bool), typeof(XOnOffDisplay), new FrameworkPropertyMetadata(new PropertyChangedCallback(OnChangeChecked)));

		public bool Checked
		{
			set { SetValue(PropertyChecked, value); }
			get { return (bool)GetValue(PropertyChecked); }
		}


		public static void OnChangeChecked(DependencyObject sender, DependencyPropertyChangedEventArgs e)
		{
			XOnOffDisplay OnOffDisp = sender as XOnOffDisplay;
			if (OnOffDisp != null)
			{
				OnOffDisp.UpdateDispColor();
				if (OnOffDisp.Checked == true)
				{
					OnOffDisp.rcCheck.Fill = OnOffDisp.OnColor;
				}
				else
				{
					OnOffDisp.rcCheck.Fill = OnOffDisp.OffColor;
				}				
			}
		}


		public OnOffDisplayMode IndigateDisplayMode
		{
			get
			{
				return dispMode;
			}
			set
			{
				if (dispMode != value)
				{
					dispMode = value;
					if (dispMode == OnOffDisplayMode.fullRect )
					{
						Grid.SetColumnSpan(rcCheck, 2);
						rcCheck.Margin = new Thickness(0,0,0,0);
						Grid.SetColumn(lblDesc, 0);
						Grid.SetColumnSpan(lblDesc, 2);
						lblDesc.HorizontalContentAlignment = HorizontalAlignment.Center;
					}
					else
					{
						Grid.SetColumnSpan(rcCheck, 1);
						rcCheck.Margin = new Thickness(5, 5, 5, 5);
						Grid.SetColumn(lblDesc, 1);
						Grid.SetColumnSpan(lblDesc, 1);
						lblDesc.HorizontalContentAlignment = HorizontalAlignment.Left;
					}
				}

			}
		}
		private void UpdateDispColor()
		{
			if (this.Checked == true)
			{
				this.rcCheck.Fill = OnColor;
			}
			else
			{
				this.rcCheck.Fill = OffColor;
			}
		}

		public System.Windows.Media.Brush OnColor 
		{
			get
			{
				return onColor;
			} 
			set
			{
				if (onColor != value)
				{
					onColor = value;
					UpdateDispColor();					
				}
			}
		}

		public System.Windows.Media.Brush OffColor
		{
			get
			{
				return offColor;
			}
			set
			{
				if (offColor != value)
				{
					offColor = value;
					UpdateDispColor();
				}
			}
		}


		public System.Windows.Media.Brush TextColor
		{
			get
			{
				return lblDesc.Foreground;

			}
			set
			{
				lblDesc.Foreground = value;
			}
		}



		//public string Description
		//{
		//	get
		//	{
		//		return desc;
		//	}
		//	set
		//	{
		//		desc = value;
		//		lblDesc.Content = desc;
		//	}
		//}


		public static readonly DependencyProperty PropertyCountValue = DependencyProperty.Register("CountValue", typeof(string), typeof(XOnOffDisplay), new FrameworkPropertyMetadata(new PropertyChangedCallback(OnChangeCountValue)));

		public string CountValue
		{
			set { SetValue(PropertyCountValue, value); }
			get { return (string)GetValue(PropertyCountValue); }
		}


		public static void OnChangeCountValue(DependencyObject sender, DependencyPropertyChangedEventArgs e)
		{
			XOnOffDisplay CntDisp = sender as XOnOffDisplay;
			if (CntDisp != null)
			{
				CntDisp.lblDesc.Content = CntDisp.CountValue.ToString();
			}
		}

	}
}
